import ruon.jiao.JIAO;

import java.io.*;
import java.util.Scanner;

/**
 *
 * House Arrest (ver 1.0) - jiao API ruon.jiao.sample.HouseArrestAgent
 *
 * This sample shows the use of the JIAO (Java-I-Am-ON) API.
 * It is basically a house-arrest application:
 * The user has to prove he is in the house (keep-alive) and
 * can also complain about basic needs (alarms).
 *
 * This is just a sample application and is not recommended to
 * be used by law enforcement agencies.
 *
 * Using the Scanner Object this file needs Java 5. Feel free to change it.
 *
 * Good luck...
 * The R-U-ON Team
 *
 */

public class HouseArrestAgent {

    public static void main(String [] argv) {
        try {

            String agentId;

            JIAO jiao = new JIAO("houseArrest", "1.0");

            try {
                // Load the agent id if saved from a previous execution
                agentId = loadId();
                jiao.setAgentId(agentId);
            } catch (FileNotFoundException e) {
                // Register the agent and save the id
                stdout.println("Register prisoner - enter your account id (R-U-ON->Settings->Account):");
                String accountId = stdin.next();
                agentId = jiao.register(accountId);
                stdout.println("Prisoner registered");
                saveId(agentId);
            }

            JIAO.Directive directive = null;
            do {
                if (directive!=null) {
                    int sleep = Integer.parseInt(directive.getX());
                    stdout.println("Good night - you can sleep for "+sleep+" seconds");
                    stdout.println();
                    Thread.sleep(1000*sleep);
                }

                stdout.println("Good Morning - Please select one of the following: ");
                stdout.println("1. I am still here");
                stdout.println("2. Everything is okay");
                stdout.println("3. I am hungry");
                stdout.println("4. The roof is leaking");
                stdout.println("5. I have escaped");
                int choice = Integer.parseInt(stdin.next());
                switch (choice) {
                    case 1:
                        directive = jiao.keepAlive();
                        break;
                    case 2:
                        directive = jiao.reportAlarms(new JIAO.IAlarm[]{}, false);
                        break;
                    case 3: {
                        JIAO.Alarm alarm = new JIAO.Alarm("Prisoner", "HUNGER", JIAO.IAlarm.MAJOR, "Prisoner is hungry");
                        directive = jiao.reportAlarms(new JIAO.IAlarm[]{alarm}, true);
                        break;}
                    case 4: {
                        JIAO.Alarm alarm = new JIAO.Alarm("House", "ROOFLEAK", JIAO.IAlarm.MINOR, "The roof is leaking");
                        directive = jiao.reportAlarms(new JIAO.IAlarm[]{alarm}, true);
                        break;}
                    case 5:
                    default: {
                        JIAO.Alarm alarm = new JIAO.Alarm("Prisoner", "ESCAPED", JIAO.IAlarm.CRITICAL, "The prisoner has escaped!");
                        directive = jiao.reportAlarms(new JIAO.IAlarm[]{alarm}, false); // false cause if this happened, all other alarms should be cleared
                        break;}
                }
            } while (directive.getVerb()==JIAO.Directive.SLEEP);

            if (directive.getVerb()==JIAO.Directive.UNINSTALL) {
                stdout.println("Uninstall...");
                deleteId();
            } else {
                stdout.println("Got a special directive (not implemented for sample): "+directive);
            }
            stdout.println("Terminating");

        } catch (Exception e) {
            e.printStackTrace();
        }
    }



    // Some support functions beyond this point:

    final private static String idfile = "c:/agentid.ruon"; // Not a good place? Change it...
    private static Scanner stdin = new Scanner(System.in, "ISO-8859-1");
    private static PrintStream stdout = System.out;
    private static void saveId(String id) throws IOException {
        OutputStream os = new FileOutputStream(idfile);
        try {
            new ObjectOutputStream(os).writeObject(id);
        } finally {
            os.close();
        }
    }
    private static String loadId() throws IOException, ClassNotFoundException {
        InputStream is = new FileInputStream(idfile);
        try {
            return (String) (new ObjectInputStream(is).readObject());
        } finally {
            is.close();
        }
    }
    private static void deleteId() {
        File f = new File(idfile);
        f.delete();
    }


}
